@@ -14,24 +14,22 @@ jQuery(function($){
 
   var print_images = function(obj){
     // Fold functionality always
-    if($('.documentEditable').length !== 0){
-      var actions = '<div class="portletActionsWrapper">';
-      if (obj.parents('.portletwrapper:first').hasClass('folded')) {
-        actions += "<a class='dashboardButton buttonOpen' href='#'>&nbsp;</a>";
-      }
-      else{
-        actions+="<a class='dashboardButton buttonClose' href='#'>&nbsp;</a>";
-      }
-      //Hash auslessen
-      var hash = obj.parents('.portletwrapper:first').attr('id').substr('portletwrapper-'.length);
-      actions += '<span class="dashboardButton buttonMove">&nbsp;</span>';
-      if (obj.parents('.portletwrapper:first').hasClass('editable')) {
-        actions += '<a class="dashboardButton buttonEdit" href="dashboardEditLinkView?hash='+hash+'">&nbsp;</a>';
-      }
-      actions += '<a class="dashboardButton buttonRemove" href="#">&nbsp;</a>';
-      actions += '</div>';
-      $(actions).insertAfter($('.portletTopLeft',obj));
+    var actions = '<div class="portletActionsWrapper">';
+    if (obj.parents('.portletwrapper:first').hasClass('folded')) {
+      actions += "<a class='dashboardButton buttonOpen' href='#'>&nbsp;</a>";
     }
+    else{
+      actions+="<a class='dashboardButton buttonClose' href='#'>&nbsp;</a>";
+    }
+    //Hash auslessen
+    var hash = obj.parents('.portletwrapper:first').attr('id').substr('portletwrapper-'.length);
+    actions += '<span class="dashboardButton buttonMove">&nbsp;</span>';
+    if (obj.parents('.portletwrapper:first').hasClass('editable')) {
+      actions += '<a class="dashboardButton buttonEdit" href="dashboardEditLinkView?hash='+hash+'">&nbsp;</a>';
+    }
+    actions += '<a class="dashboardButton buttonRemove" href="#">&nbsp;</a>';
+    actions += '</div>';
+    $(actions).appendTo(obj);
   };
 
   var authenticator_token = $('.dashboardContent').data('authenticator-token');
@@ -123,7 +121,7 @@ jQuery(function($){
   });
 
   /* TOGGLE PORTLET CONTENT */
-  $('.portletHeader a.buttonOpen, .portletHeader a.buttonClose').live('click',function(e) {
+  $('#dashboard').on('click', '.portletHeader a.buttonOpen, .portletHeader a.buttonClose',function(e) {
     e.preventDefault();
     $(this).parents('.portletwrapper:first').toggleClass('folded');
     //Change icon
@@ -152,7 +150,7 @@ jQuery(function($){
   });
 
   // This is needed when the calendar reloads to display the next month
-  $('.portletwrapper .portletHeader a').live('click', function(){
+  $('#dashboard').on('click', '.portletwrapper .portletHeader a', function(){
     $(this).append($('<div class="resetIcons"></div>'));
     var wrapper = $(this).parents('.portletwrapper:first');
     var column = wrapper.parents('.dashboard-column:first');
@@ -169,7 +167,7 @@ jQuery(function($){
   });
 
   /* REMOVE PORTLET */
-  $('.portletHeader a.buttonRemove').live('click',function(e) {
+  $('#dashboard').on('click', '.portletHeader a.buttonRemove', function(e) {
     e.preventDefault();
     var wrapper = $(this).parents('.portletwrapper:first');
     var hash = wrapper.attr('id').substr('portletwrapper-'.length);
@@ -208,7 +206,7 @@ jQuery(function($){
   });
 
   /* REMOVE Favourite*/
-  $('.portletFavourites .close.favRemove').live('click',function(e){
+  $('#dashboard').on('click', '.portletFavourites .close.favRemove',function(e){
     var uid = $(this).attr('id');
     $.post('./ftw_dashboard_dragndrop_remove_favorite',{ uid : uid },function(data){
       if (data===''){
